@@ -31,7 +31,7 @@ bin:\
 /usr/local/share/java/opennlp-tools-1.3.0.jar:\
 /usr/local/share/java/maxent-2.4.0.jar:\
 /usr/local/share/java/trove.jar:\
-/usr/local/share/java/link-grammar-4.3.7.jar:\
+/usr/local/share/java/linkgrammar-4.4.0.jar:\
 /usr/share/java/commons-logging.jar:\
 /usr/share/java/gnu-getopt.jar:\
 /usr/share/java/xercesImpl.jar:\
