@@ -43,14 +43,13 @@ import relex.feature.LinkView;
 import relex.frame.Frame;
 import relex.morphy.Morphy;
 import relex.morphy.MorphyFactory;
-import relex.output.OpenCogXML;
+import relex.output.OpenCogScheme;
 import relex.output.ParseView;
 import relex.output.RawView;
 import relex.output.SimpleView;
-import relex.parser.LinkParser;
-import relex.parser.LinkParserClient;
-import relex.parser.LinkParserJNINewClient;
-import relex.parser.LinkParserSocketClient;
+import relex.parser.LGParser;
+import relex.parser.LocalLGParser;
+import relex.parser.RemoteLGParser;
 import relex.stats.TruthValue;
 import relex.stats.SimpleTruthValue;
 import relex.tree.PhraseMarkup;
@@ -82,7 +81,7 @@ public class RelationExtractor
 	private RelexContext context;
 
 	/** Syntax processing */
-	private LinkParser parser;
+	private LGParser parser;
 
 	/** Semantic processing */
 	private SentenceAlgorithmApplier sentenceAlgorithmApplier;
@@ -91,10 +90,14 @@ public class RelationExtractor
 	private PhraseMarkup phraseMarkup;
 
 	/** Anaphora resolution */
+	// XXX these should probably be moved to class Document!
 	public Antecedents antecedents;
 	private Hobbs hobbs;
 	public boolean do_anaphora_resolution;
 
+	/** Document - holder of sentences */
+	Document doco;
+
 	/** Statistics */
 	private ParseStats stats;
 
@@ -111,12 +114,10 @@ public class RelationExtractor
 	}
 	private void init(boolean useSocket)
 	{
-		parser = new LinkParser();
-
-		LinkParserClient lpc = (useSocket) ? new LinkParserSocketClient() : LinkParserJNINewClient.getSingletonInstance();
-		lpc.init();
+		parser = useSocket ? new RemoteLGParser() : new LocalLGParser();
+		parser.getConfig().setStoreConstituentString(true);
 		Morphy morphy = MorphyFactory.getImplementation(MorphyFactory.DEFAULT_SINGLE_THREAD_IMPLEMENTATION);
-		context = new RelexContext(lpc, morphy);
+		context = new RelexContext(parser, morphy);
 
 		sentenceAlgorithmApplier = new SentenceAlgorithmApplier();
 
@@ -129,6 +130,8 @@ public class RelationExtractor
 		hobbs = new Hobbs(antecedents);
 		do_anaphora_resolution = false;
 
+		doco = new Document();
+
 		stats = new ParseStats();
 		sumtime = new TreeMap<String,Long>();
 		cnttime = new TreeMap<String,Long>(); 
@@ -136,7 +139,9 @@ public class RelationExtractor
 
 	String getVersion()
 	{
-		return context.getLinkParserClient().getVersion();
+		// return parser.getVersion();
+		// Temporary hack unil the new bindings are fixed up.
+		return "XXX Broken -- FIXME";
 	}
 
 	/* ---------------------------------------------------------- */
@@ -146,20 +151,21 @@ public class RelationExtractor
 	 * This will NOT reduce processing time; all parses are still computed,
 	 * but only this many are returned.
 	 */
-	public void setMaxParses(int maxParses) {
-		context.getLinkParserClient().setMaxParses(maxParses);
+	public void setMaxParses(int maxParses)
+	{
+		parser.getConfig().setMaxLinkages(maxParses);
 	}
 
 	public void setMaxCost(int maxCost) {
-		context.getLinkParserClient().setMaxCost(maxCost);
+		parser.getConfig().setMaxCost(maxCost);
 	}
 
 	public void setAllowSkippedWords(boolean allow) {
-		context.getLinkParserClient().setAllowSkippedWords(allow);
+		parser.getConfig().setAllowSkippedWords(allow);
 	}
 
 	public void setMaxParseSeconds(int maxParseSeconds) {
-		context.getLinkParserClient().setMaxParseSeconds(maxParseSeconds);
+		parser.getConfig().setMaxParseSeconds(maxParseSeconds);
 	}
 
 	/* ---------------------------------------------------------- */
@@ -178,12 +184,12 @@ public class RelationExtractor
 		hobbs = new Hobbs(antecedents);
 	}
 
-	public RelexInfo processSentence(String sentence)
+	public Sentence processSentence(String sentence)
 	{
 		return processSentence(sentence, null);
 	}
 
-	public RelexInfo processSentence(String sentence,
+	public Sentence processSentence(String sentence,
 	                                 EntityMaintainer entityMaintainer)
 	{
 		starttime = System.currentTimeMillis();
@@ -193,14 +199,14 @@ public class RelationExtractor
 		                               new ArrayList<EntityInfo>());
 		}
 
-		RelexInfo ri = null;
+		Sentence sntc = null;
 		try
 		{
 			if (verbosity > 0) starttime = System.currentTimeMillis();
-			ri = parseSentence(sentence, entityMaintainer);
+			sntc = parseSentence(sentence, entityMaintainer);
 			if (verbosity > 0) reportTime("Link-parsing: ");
 
-			for (ParsedSentence parse : ri.getParses())
+			for (ParsedSentence parse : sntc.getParses())
 			{
 				// Markup feature node graph with entity info,
 				// so that the relex algs (next step) can see them.
@@ -222,13 +228,13 @@ public class RelationExtractor
 			}
 
 			// Assign a simple parse-ranking score, based on LinkGrammar data.
-			ri.simpleParseRank();
+			sntc.simpleParseRank();
 
 			// Perform anaphora resolution
 			if (do_anaphora_resolution)
 			{
-				hobbs.addParse(ri);
-				hobbs.resolve(ri);
+				hobbs.addParse(sntc);
+				hobbs.resolve(sntc);
 			}
 		}
 		catch(Exception e)
@@ -236,8 +242,8 @@ public class RelationExtractor
 			System.err.println("Failed to process sentence: " + sentence);
 			e.printStackTrace();
 		}
-		if (verbosity > 0) reportTime("Relex processing: ");
-		return ri;
+		if (verbosity > 0) reportTime("RelEx processing: ");
+		return sntc;
 	}
 
 	/**
@@ -245,7 +251,7 @@ public class RelationExtractor
 	 * currentParses is filled with the ParsedSentences Uses an optional
 	 * EntityMaintainer to work on a converted sentence.
 	 */
-	private RelexInfo
+	private Sentence
 	parseSentence(String sentence, EntityMaintainer entityMaintainer)
 	{
 		if (entityMaintainer != null) {
@@ -254,15 +260,15 @@ public class RelationExtractor
 		if (sentence == null) return null;
 
 		String orig_sentence = entityMaintainer.getOriginalSentence();
-		RelexInfo ri = null;
+		Sentence sent = null;
 		if (sentence.length() < DEFAULT_MAX_SENTENCE_LENGTH) {
-			ri = parser.parse(sentence, context.getLinkParserClient());
+			sent = parser.parse(sentence);
 		} else {
 			System.err.println("Sentence too long!: " + sentence);
-			ri = new RelexInfo();
+			sent = new Sentence();
 		}
-		ri.setSentence(orig_sentence);
-		return ri;
+		sent.setSentence(orig_sentence);
+		return sent;
 	}
 
 	/* ---------------------------------------------------------- */
@@ -404,9 +410,9 @@ public class RelationExtractor
 			return;
 		}
 
-		// If generating OpenCog XML, delimit non-xml output.
+		// If generating OpenCog Scheme, delimit output.
 		if (commandMap.get("-o") != null)
-			System.out.print("data\n<!-- ");
+			System.out.print("scm\n");
 
 		RelationExtractor re = new RelationExtractor(false);
 		re.setAllowSkippedWords(true);
@@ -435,32 +441,26 @@ public class RelationExtractor
 		// QuotesParensSentenceDetector ds = QuotesParensSentenceDetector.create();
 
 		ParseView ceregoView = new ParseView();
-		OpenCogXML opencog = new OpenCogXML();
+		OpenCogScheme opencog = new OpenCogScheme();
 
 		Frame frame = null;
 		if (commandMap.get("-f") != null) frame = new Frame();
 
 		int sentence_count = 0;
-		while(true)
+		boolean more_input = true;
+		while(more_input)
 		{
 			// If no sentence specified on the command line
 			// (with the "-s" flag), then read it from stdin.
 			while (sentence == null)
 			{
-				System.out.print("% ");
 				try {
 					sentence = stdin.readLine();
 					if ((sentence == null) || "END.".equals(sentence))
 					{
-						System.out.println("Bye.");
-						if (commandMap.get("-o") != null)
-						{
-							System.out.print("-->\n");
-							char[] eot = new char[1];
-							eot[0] = 0x4;
-							System.out.println(new String (eot));
-						}
-						return;
+						more_input = false;
+						sentence = null;
+						break;
 					}
 				} catch (IOException e) {
 					System.err.println("Error reading sentence from the standard input!");
@@ -474,7 +474,7 @@ public class RelationExtractor
 
 			while (sentence != null)
 			{
-				System.out.println("SENTENCE: ["+sentence+"]");
+				System.out.println("; SENTENCE: ["+sentence+"]");
 				EntityMaintainer em = null;
 				if (gem != null)
 				{
@@ -482,13 +482,13 @@ public class RelationExtractor
 					em = gem.makeEntityMaintainer(sentence);
 					re.reportTime("Gate processing: ");
 				}
-
-				RelexInfo ri = re.processSentence(sentence,em);
+				Sentence sntc = re.processSentence(sentence,em);
+				re.doco.addSentence(sntc);
 
 				sentence_count ++;
-				re.stats.bin(ri);
+				re.stats.bin(sntc);
 
-				int np = ri.getParses().size();
+				int np = sntc.getParses().size();
 				if (np > maxParses) np = maxParses;
 
 				// chunk ranking stuff
@@ -503,12 +503,15 @@ public class RelationExtractor
 
 				// Print output
 				int numParses = 0;
-				for (ParsedSentence parse: ri.getParses())
+				for (ParsedSentence parse: sntc.getParses())
 				{
-					System.out.println(sentence);
-					System.out.println("\n====\n");
-					System.out.println("Parse " + (numParses+1) +
-					             " of " + ri.getParses().size());
+					if (commandMap.get("-o") == null)
+					{
+						System.out.println(sentence);
+						System.out.println("\n====\n");
+						System.out.println("Parse " + (numParses+1) +
+					             	" of " + sntc.getParses().size());
+					}
 
 					if (commandMap.get("-r") != null)
 					{
@@ -531,21 +534,27 @@ public class RelationExtractor
 						System.out.println(parse.getMetaData().toString() + "\n");
 					}
 
-					// Print simple parse ranking
-					Double confidence = parse.getTruthValue().getConfidence();
-					String pconfidence = confidence.toString().substring(0,6);
-					System.out.println("Parse confidence: " + pconfidence);
-					System.out.println(
-						"cost vector = (UNUSED=" + parse.getNumSkippedWords() +
-						" DIS=" + parse.getDisjunctCost() +
-						" AND=" + parse.getAndCost() +
-						" LEN=" + parse.getLinkCost() + ")");
+					if (commandMap.get("-o") == null)
+					{
+						// Print simple parse ranking
+						Double confidence = parse.getTruthValue().getConfidence();
+						String pconfidence = confidence.toString().substring(0,6);
+						System.out.println("Parse confidence: " + pconfidence);
+						System.out.println(
+							"cost vector = (UNUSED=" + parse.getNumSkippedWords() +
+							" DIS=" + parse.getDisjunctCost() +
+							" AND=" + parse.getAndCost() +
+							" LEN=" + parse.getLinkCost() + ")");
+					}
 
 					// Verbose graph.
 					if (commandMap.get("-v") != null)
-						System.out.println("\n" + parse.getLeft().toString(LinkView.getFilter()));
+						// System.out.println("\n" + parse.fullParseString());
+						System.out.println("\n" + 
+						 	parse.getLeft().toString(LinkView.getFilter()));
 
-					if (commandMap.get("-q") == null)
+					if ((commandMap.get("-q") == null) &&
+					    (commandMap.get("-o") == null))
 					{
 						System.out.println("\n======\n");
 						System.out.println(SimpleView.printRelations(parse));
@@ -607,14 +616,8 @@ public class RelationExtractor
 					}
 					if (commandMap.get("-o") != null)
 					{
-						System.out.print("-->\n");
 						opencog.setParse(parse);
 						System.out.println(opencog.toString());
-
-						char[] eot = new char[1];
-						eot[0] = 0x4;
-						System.out.println(new String (eot));
-						System.out.println("data\n<!-- ======\n");
 					}
 
 					if (++numParses >= maxParses) break;
@@ -636,13 +639,20 @@ public class RelationExtractor
 				// Print out the stats every now and then.
 				if (sentence_count%5 == 0)
 				{
-					System.out.println ("\n" + re.stats.toString());
+					System.err.println ("\n" + re.stats.toString());
 				}
 
 				sentence = ds.getNextSentence();
 			}
 			if (commandMap.get("-s") != null) break;
 		}
+
+		// Dump the list of document sentences
+		if (commandMap.get("-o") != null)
+		{
+			System.out.println(opencog.printDocument(re.doco));
+		}
+		System.out.println("; Bye.");
 	}
 }
 
