@@ -20,10 +20,9 @@ import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.Callable;
 
 import relex.ParsedSentence;
-import relex.RelexInfo;
+import relex.Sentence;
 import relex.algs.SentenceAlgorithmApplier;
 import relex.entity.EntityMaintainer;
-import relex.parser.LinkParser;
 import relex.tree.PhraseMarkup;
 
 /**
@@ -40,8 +39,7 @@ public class RelexTask implements Callable<RelexTaskResult>
 	private String sentence;
 	private EntityMaintainer entityMaintainer;
 	
-	// Reusable, shared processors
-	private LinkParser lp; 
+	// Reusable, shared processors 
 	private SentenceAlgorithmApplier sentenceAlgorithmApplier;
 	private PhraseMarkup phraseMarkup;
 
@@ -50,14 +48,12 @@ public class RelexTask implements Callable<RelexTaskResult>
 	private BlockingQueue<RelexContext> pool;
 	
 	public RelexTask(int index, String sentence,
-			EntityMaintainer entityMaintainer,
-			LinkParser lp, 
+			EntityMaintainer entityMaintainer, 
 			SentenceAlgorithmApplier sentenceAlgorithmApplier,
 			PhraseMarkup phraseMarkup,
 			RelexContext context, BlockingQueue<RelexContext> pool){
 		this.index = index;
-		this.entityMaintainer = entityMaintainer;
-		this.lp = lp; 
+		this.entityMaintainer = entityMaintainer; 
 		this.sentenceAlgorithmApplier = sentenceAlgorithmApplier;
 		this.phraseMarkup = phraseMarkup;
 		this.context = context;
@@ -68,20 +64,20 @@ public class RelexTask implements Callable<RelexTaskResult>
 	public RelexTaskResult call() {
 		try {
 			if (DEBUG > 0) System.out.println("[" + index + "] Start processing "+ sentence);
-			String convertedSentence = entityMaintainer.getConvertedSentence();
+			String convertedSentence = entityMaintainer.getConvertedSentence().replace('\n', ' ').replace('\r', ' ');
 			if (DEBUG > 0) System.out.println("[" + index + "] End entity detection");
-			RelexInfo ri = null;
+			Sentence sntc = null;
 			try {
-				ri = lp.parse(convertedSentence, context.getLinkParserClient());
+				sntc = context.getParser().parse(convertedSentence);//, context.getLinkParserClient());
 			} catch (RuntimeException ex) {
-				ri = new RelexInfo();
-				ri.setSentence(sentence);
+				sntc = new Sentence();
+				sntc.setSentence(sentence);
 			}
 			
 			if (DEBUG > 0) System.out.println("[" + index + "] End parsing");
 
 			int i = 0;
-			for (ParsedSentence parse : ri.getParses()) {
+			for (ParsedSentence parse : sntc.getParses()) {
 				try {
 					// Markup feature node graph with entity info,
 					// so that the relex algs (next step) can see them.
@@ -95,15 +91,16 @@ public class RelexTask implements Callable<RelexTaskResult>
 					entityMaintainer.repairSentence(parse.getLeft());
 
 					// Also do a Penn tree-bank style phrase structure markup.
-					phraseMarkup.markup(parse);
+					if (phraseMarkup != null)
+						phraseMarkup.markup(parse);
 				} catch (Exception e) {
 					e.printStackTrace();
 				}
 				if (DEBUG > 0) 
 					System.out.println("[" + index+ "] end post-processing sentence " + 
-							(i++) + "/"+ ri.getParses().size());
+							(i++) + "/"+ sntc.getParses().size());
 			}
-			return new RelexTaskResult(index, sentence, entityMaintainer, ri);
+			return new RelexTaskResult(index, sentence, entityMaintainer, sntc);
 		} finally {
 			if (DEBUG > 0)
 				System.out.println("[" + index + "] End processing");
@@ -116,7 +113,8 @@ public class RelexTask implements Callable<RelexTaskResult>
 		}
 	}
 	
-	public String toString(){
-		return index+": "+sentence;
+	public String toString()
+	{
+		return index + ": " + sentence;
 	}
 }
