@@ -24,8 +24,9 @@ import org.linkgrammar.LinkGrammar;
  * The abstract interface to the C linkparser. Extensions of this class can link
  * directly to the linkparser through JNI, or through some other call method
  * such as Sockets
+ * 
+ * @deprecated
  */
-
 public abstract class LinkParserClient
 {
 	// ServerParams are parameters that are used by the link parser c code
@@ -81,7 +82,7 @@ public abstract class LinkParserClient
 
 	public void init(String linkGrammarDictionariesPath) {
 		if (linkGrammarDictionariesPath==null) {
-			System.out.println("Using default relex.linkparserpath");
+			System.err.println("Info: Using default relex.linkparserpath");
 		} else {
 			File dir = new File(linkGrammarDictionariesPath);
 			if (!dir.isDirectory() || !dir.canRead()) 
@@ -89,7 +90,7 @@ public abstract class LinkParserClient
 						"Error reading default relex.linkparserpath" :
 						"Error reading relex.linkparserpath: "+linkGrammarDictionariesPath);
 			try {
-				System.out.println("Using relex.linkparserpath: "+dir.getCanonicalPath());
+				System.err.println("Info: Using relex.linkparserpath: "+dir.getCanonicalPath());
 				LinkGrammar.setDictionariesPath(linkGrammarDictionariesPath);
 			} catch (Throwable t){
 				throw new IllegalArgumentException("Invalid relex.linkparserpath: "+linkGrammarDictionariesPath);			
