@@ -16,10 +16,12 @@
 
 package relex.parser;
 
-import relex.RelexInfo;
+import relex.Sentence;
 
 /**
  * The interface to
+ * 
+ * @deprecated
  */
 public abstract class Parser
 {
@@ -31,7 +33,7 @@ public abstract class Parser
 	 * @return a list of parses and supporting information.
 	 *
 	 */
-	public abstract RelexInfo parse(String sentence, LinkParserClient lpc);
+	public abstract Sentence parse(String sentence, LinkParserClient lpc);
 
 	/**
 	 * Given a sentence, returns a string representation of a parse of that sentence.
